/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.isobus.tree;

import java.util.List;
import nl.cloudfarming.client.isobus.model.AllocationTime;
import nl.cloudfarming.client.isobus.model.Position;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.NbBundle;

/**
 * Node for the {@link AllocationTime} Object
 *
 * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
 */
@NbBundle.Messages("isobus project taskdata node name allocationtime=AllocationTime ({0} - {1})")
public class AllocationStampNode extends AbstractNode {

    private static final String ALLOCATION_TIME_NODE_ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_allocation_time.png";

    public AllocationStampNode(AllocationTime allocationTime) {
        super(Children.create(new AllocationStampChildFactory(allocationTime), true));
        setName(Bundle.isobus_project_taskdata_node_name_allocationtime(allocationTime.getStartTime(), allocationTime.getEndTime()));
        setIconBaseWithExtension(ALLOCATION_TIME_NODE_ICON);
    }

    /**
     * <p>Child factory for {@link AllocationTime} object</p>
     * Possible children are {@link Position}
     *
     * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
     */
    static class AllocationStampChildFactory extends ChildFactory<Position> {

        private final AllocationTime allocationTime;

        public AllocationStampChildFactory(AllocationTime allocationTime) {
            this.allocationTime = allocationTime;
        }

        @Override
        protected boolean createKeys(List<Position> toPopulate) {
            Position position = allocationTime.getPosition();
            if (position != null) {
                toPopulate.add(position);
            }
            return true;
        }

        @Override
        protected Node createNodeForKey(Position position) {
            return new PositionNode(position);
        }
    }
}
