/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.isobus.tree;

import java.util.List;
import nl.cloudfarming.client.isobus.model.Connection;
import nl.cloudfarming.client.isobus.model.DeviceElement;
import nl.cloudfarming.client.isobus.model.IsobusDevice;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Node;

/**
 * <p>Child factory for the {@link Connection} object</p> <p>Possible children
 * are 2 times {@link IsobusDevicece} and 2 times {@link DeviceElement}</p>
 *
 * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
 */
public class ConnectionChildFactory extends ChildFactory<Node> {
    
    private Connection connection;
    
    public ConnectionChildFactory(Connection connection) {
        this.connection = connection;        
    }
    
    @Override
    protected boolean createKeys(List<Node> toPopulate) {
        //Device (DVC) Device ref 1
        IsobusDevice device1 = (IsobusDevice) connection.getDeviceId0();
        if (device1 != null) {
            toPopulate.add(new DeviceNode(device1));
        }

        //DeviceElement (DET) Device element ref 1
        DeviceElement deviceElement1 = (DeviceElement) connection.getDeviceElementId0();
        if(deviceElement1 != null){
            toPopulate.add(new DeviceElementNode(deviceElement1));
        }

        //Device (DVC) Device ref 2
        IsobusDevice device2 = (IsobusDevice) connection.getDeviceId1();
        if (device1 != null) {
            toPopulate.add(new DeviceNode(device2));
        }
        //DeviceElement (DET) Device element ref 2
        DeviceElement deviceElement2 = (DeviceElement) connection.getDeviceElementId1();
        if(deviceElement1 != null){
            toPopulate.add(new DeviceElementNode(deviceElement2));
        }
        
        return true;
    }
    
    @Override
    protected Node createNodeForKey(Node key) {
        return key;
    }
}
