/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.isobus.tree;

import java.util.List;
import nl.cloudfarming.client.isobus.model.Customer;
import nl.cloudfarming.client.isobus.model.IsobusFarm;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.NbBundle;
import org.openide.util.lookup.Lookups;

/**
 * Node for {@link IsobusFarm} object
 * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
 */
@NbBundle.Messages({
    "isobus project farm node name=Farm ({0})"
})
public class FarmNode extends AbstractNode {

    private static final String ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_farm.png";

    public FarmNode(IsobusFarm farm) {
        super(Children.create(new FarmChildFactory(farm), true), Lookups.fixed(farm));
        setName(Bundle.isobus_project_farm_node_name(farm.getName()));
        setIconBaseWithExtension(ICON);
    }

    /**
     * Child factory for a {@link IsobusFarm} Farm references a {@link Customer}
     *
     * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
     */
    static class FarmChildFactory extends ChildFactory<Node> {

        private IsobusFarm isobusFarm;

        public FarmChildFactory(IsobusFarm isobusFarm) {
            this.isobusFarm = isobusFarm;
        }

        @Override
        protected boolean createKeys(List<Node> toPopulate) {
            if (isobusFarm.getCustomerIdRef() != null) {
                toPopulate.add(new CustomerNode((Customer) isobusFarm.getCustomerIdRef()));
            }
            return true;

        }

        @Override
        protected Node createNodeForKey(Node key) {
            return key;
        }
    }
}
