/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.isobus.tree;

import java.util.List;
import nl.cloudfarming.client.isobus.model.DataLogValue;
import nl.cloudfarming.client.isobus.model.IsobusTime;
import nl.cloudfarming.client.isobus.model.Position;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.NbBundle.Messages;

/**
 * Node factory for the {@link IsobusTime} Object Possible children are {@link Position}
 * and {@link DataLogValue}
 *
 * @author Gerben Feenstra
 */
@Messages({
    "isobus project taskdata node name datalog values=Datalog values"
})
public class TimeChildFactory extends ChildFactory<Node> {

    private static final String DATALOGVALUE_NODE_ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_data_log_value.png";
    private final IsobusTime time;

    public TimeChildFactory(IsobusTime time) {
        this.time = time;
    }

    @Override
    protected boolean createKeys(List<Node> toPopulate) {
        // Position (PTN)
        Position position = time.getPTN();
        if (position != null) {
            toPopulate.add(new PositionNode(position));
        }

        // DataLogValue (DLV)
        if (!time.getDLV().isEmpty()) {
            Children dataLogValueChildren = Children.create(new AggregateNodeChildFactory<>(time.getDLV()), true);
            String displayName = Bundle.isobus_project_taskdata_node_name_datalog_values();
            toPopulate.add(new IsobusAggregateNode(dataLogValueChildren, DATALOGVALUE_NODE_ICON, displayName));
        }
        return true;
    }

    @Override
    protected Node createNodeForKey(Node node) {
        return node;
    }
}
